==> nui_theme-0.0.22.tar.gz: lib/nui_theme_widget.dart <==
import 'package:flutter/widgets.dart';
import 'package:nui_core/busevent/nui_busevent.dart';
import 'package:nui_core/nui_core.dart';
import 'nui_theme.dart';

typedef NUIThemeChildBuilder = Widget Function(BuildContext context, NUIColorTheme theme);

class NUIThemeContainer extends StatefulWidget {
  NUIThemeContainer({@required this.builder});
  final NUIThemeChildBuilder builder;

  @override
  NUIThemeContainerState createState() => NUIThemeContainerState();
  static NUIThemeContainerState of(BuildContext context) => context.findAncestorStateOfType<NUIThemeContainerState>();
}

class NUIThemeContainerState extends State<NUIThemeContainer> {
  String _identity;

  @override
  void initState(){
    super.initState();
    _identity = randomUUID();
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).listenInvoke(_identity, listener: (event){
      if(match(event.code, NUITheme.CODE_THEME_SWITCHED)){
        //Theme switched
        logNUI("NUIThemeContainer", "Switching theme ...");
        setState(() {
          //Calling set state to update the items and their theme color
        });
      }
    });
  }

  void refresh(){
    setState(() {

    });
  }

  @override
  void dispose(){
    super.dispose();
    logNUI("NUIThemeContainer", "Disposed bus event listener");
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).disposeInvoke(_identity);
  }

  @override
  Widget build(BuildContext context) {
    final currentTheme = colorTheme;
    return widget.builder(context, currentTheme);
  }
}

class NUIThemeParentContainer extends StatefulWidget {
  NUIThemeParentContainer({@required this.builder});
  final NUIThemeChildBuilder builder;

  @override
  NUIThemeParentContainerState createState() => NUIThemeParentContainerState();
  static NUIThemeParentContainerState of(BuildContext context) => context.findAncestorStateOfType<NUIThemeParentContainerState>();
}

class NUIThemeParentContainerState extends State<NUIThemeParentContainer> {
  String _identity;

  @override
  void initState(){
    super.initState();
    _identity = randomUUID();
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).listenInvoke(_identity, listener: (event){
      if(match(event.code, NUITheme.CODE_THEME_SWITCHED)){
        //Theme switched
        logNUI("NUIThemeContainer", "Switching theme ...");
        setState(() {
          //Calling set state to update the items and their theme color
        });
      }
    });
  }

  void refresh(){
    setState(() {

    });
  }

  @override
  void dispose(){
    super.dispose();
    logNUI("NUIThemeContainer", "Disposed bus event listener");
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).disposeInvoke(_identity);
  }

  @override
  Widget build(BuildContext context) {
    final currentTheme = colorTheme;
    return widget.builder(context, currentTheme);
  }
}

==> nui_theme-1.0.3.tar.gz: lib/nui_theme_widget.dart <==
import 'package:flutter/widgets.dart';
import 'package:nui_core/busevent/nui_busevent.dart';
import 'package:nui_core/nui_core.dart';
import 'nui_theme.dart';

typedef NUIThemeChildBuilder = Widget Function(BuildContext context, NUIColorTheme theme);

class NUIThemeContainer extends StatefulWidget {
  NUIThemeContainer({required this.builder});
  final NUIThemeChildBuilder builder;

  @override
  NUIThemeContainerState createState() => NUIThemeContainerState();
  static NUIThemeContainerState? of(BuildContext context) => context.findAncestorStateOfType<NUIThemeContainerState>();
}

class NUIThemeContainerState extends State<NUIThemeContainer> {
  late String _identity;

  @override
  void initState(){
    super.initState();
    _identity = randomUUID();
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).listenInvoke(_identity, listener: (event){
      if(match(event.code, NUITheme.CODE_THEME_SWITCHED)){
        //Theme switched
        logNUI("NUIThemeContainer", "Switching theme ...");
        setState(() {
          //Calling set state to update the items and their theme color
        });
      }
    });
  }

  void refresh(){
    setState(() {

    });
  }

  @override
  void dispose(){
    super.dispose();
    logNUI("NUIThemeContainer", "Disposed bus event listener");
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).disposeInvoke(_identity);
  }

  @override
  Widget build(BuildContext context) {
    final currentTheme = colorTheme;
    return widget.builder(context, currentTheme);
  }
}

class NUIThemeParentContainer extends StatefulWidget {
  NUIThemeParentContainer({required this.builder});
  final NUIThemeChildBuilder builder;

  @override
  NUIThemeParentContainerState createState() => NUIThemeParentContainerState();
  static NUIThemeParentContainerState? of(BuildContext context) => context.findAncestorStateOfType<NUIThemeParentContainerState>();
}

class NUIThemeParentContainerState extends State<NUIThemeParentContainer> {
  late String _identity;

  @override
  void initState(){
    super.initState();
    _identity = randomUUID();
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).listenInvoke(_identity, listener: (event){
      if(match(event.code, NUITheme.CODE_THEME_SWITCHED)){
        //Theme switched
        logNUI("NUIThemeContainer", "Switching theme ...");
        setState(() {
          //Calling set state to update the items and their theme color
        });
      }
    });
  }

  void refresh(){
    setState(() {

    });
  }

  @override
  void dispose(){
    super.dispose();
    logNUI("NUIThemeContainer", "Disposed bus event listener");
    NUIBusEvent.get(module: NUITheme.BROADCAST_THEME_MODULE).disposeInvoke(_identity);
  }

  @override
  Widget build(BuildContext context) {
    final currentTheme = colorTheme;
    return widget.builder(context, currentTheme);
  }
}
